@@ -81,7 +81,7 @@ impl Client {
         Ok(json_indexes)
     }
 
-    /// Get an [index](../indexes/struct.Index.html).
+    /// Get an [index](../indexes/struct.Index.html), this index should already exist.
     ///
     /// # Example
     ///
@@ -98,17 +98,35 @@ impl Client {
     /// # });
     /// ```
     pub async fn get_index(&self, uid: impl AsRef<str>) -> Result<Index, Error> {
-        Ok(request::<(), JsonIndex>(
-            &format!("{}/indexes/{}", self.host, uid.as_ref()),
-            &self.api_key,
-            Method::Get,
-            200,
-        ).await?
-        .into_index(self))
+        match self.get_raw_index(uid).await {
+            Ok (raw_idx) => Ok(raw_idx.into_index(self)),
+            Err(error) => Err(error),
+        }
     }
 
-    /// Assume that an [index](../indexes/struct.Index.html) exist and create a corresponding object without any check.
-    pub fn assume_index(&self, uid: impl Into<String>) -> Index {
+    /// Get a raw JSON [index](../indexes/struct.Index.html), this index should already exist.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use meilisearch_sdk::{client::*, indexes::*};
+    ///
+    /// # futures::executor::block_on(async move {
+    /// // create the client
+    /// let client = Client::new("http://localhost:7700", "masterKey");
+    /// # client.create_index("movies", None).await;
+    ///
+    /// // get the index named "movies"
+    /// let movies = client.get_raw_index("movies").await.unwrap();
+    /// # });
+    /// ```
+    /// If you use it directly from an index, you can use the method [fetch_info](#method.fetch_info), which is the equivalent method from an index.
+    pub async fn get_raw_index(&self, uid: impl AsRef<str>) -> Result<JsonIndex, Error> {
+        Index::fetch_info(&self.index(uid.as_ref())).await
+    }
+
+    /// Create a corresponding object of an [index](../indexes/struct.Index.html) without any check or doing an HTTP call.
+    pub fn index(&self, uid: impl Into<String>) -> Index {
         Index {
             uid: Rc::new(uid.into()),
             host: Rc::clone(&self.host),
@@ -157,7 +175,7 @@ impl Client {
         match self.delete_index(uid).await {
             Ok (_) => Ok(true),
             Err (Error::MeiliSearchError {
-                message: _,
+                error_message: _,
                 error_code: ErrorCode::IndexNotFound,
                 error_type: _,
                 error_link: _,
@@ -361,7 +379,18 @@ mod tests {
     #[async_test]
     async fn test_get_keys() {
         let client = Client::new("http://localhost:7700", "masterKey");
-        client.get_keys().await.unwrap();
+        let keys = client.get_keys().await.unwrap();
+        assert!(keys.private.is_some());
+        assert!(keys.public.is_some());
+    }
+
+    #[async_test]
+    async fn test_get_index() {
+        let client = Client::new("http://localhost:7700", "masterKey");
+        let index_name = "get_index";
+        client.create_index(index_name, None).await.unwrap();
+        let index = client.get_index(index_name).await.unwrap();
+        assert_eq!(index.uid.to_string(), index_name);
     }
 
     #[async_test]
@@ -409,4 +438,33 @@ mod tests {
         let deleted = client.delete_index_if_exists("bad").await.unwrap();
         assert_eq!(deleted, false);
     }
+
+    #[async_test]
+    async fn test_fetch_info() {
+        let client = Client::new("http://localhost:7700", "masterKey");
+        let index_name = "fetch_info";
+        client.create_index(index_name, None).await.unwrap();
+        let index = client.index(index_name).fetch_info().await;
+        assert!(index.is_ok());
+    }
+
+    #[async_test]
+    async fn test_get_primary_key_is_none() {
+        let client = Client::new("http://localhost:7700", "masterKey");
+        let index_name = "get_primary_key_is_none";
+        client.create_index(index_name, None).await.unwrap();
+        let primary_key = client.index(index_name).get_primary_key().await;
+        assert!(primary_key.is_ok());
+        assert!(primary_key.unwrap().is_none());
+    }
+
+    #[async_test]
+    async fn test_get_primary_key() {
+        let client = Client::new("http://localhost:7700", "masterKey");
+        let index_name = "get_primary_key";
+        client.create_index(index_name, Some("primary_key")).await.unwrap();
+        let primary_key = client.index(index_name).get_primary_key().await;
+        assert!(primary_key.is_ok());
+        assert_eq!(primary_key.unwrap().unwrap(), "primary_key");
+    }
 }
